"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createErrorLoggerMiddleware = exports.createLoggerMiddleware = exports.logger = void 0;
var process_1 = require("process");
var winston_1 = __importDefault(require("winston"));
var express_winston_1 = __importDefault(require("express-winston"));
var configs = {
    winston: {
        file: {
            level: "info",
            filename: process_1.cwd() + "/logs/access." + process.env.NODE_ENV + ".log",
            handleExceptions: true,
            json: true,
            maxsize: 5242880,
            maxFiles: 5,
            colorize: false,
        },
        console: {
            level: "debug",
            handleExceptions: true,
            json: true,
            colorize: true,
            format: winston_1.default.format.combine(winston_1.default.format.colorize(), winston_1.default.format.printf(function (info) { return info.level + ": " + JSON.stringify(info.message); })),
        },
    },
};
function filterRequestHeaders(confidentialHeaders) {
    if (confidentialHeaders === void 0) { confidentialHeaders = []; }
    return function (req, propName) {
        if (propName !== "headers")
            return req[propName];
        var filteredHeaders = Object.keys(req.headers)
            .filter(function (key) { return !confidentialHeaders.includes(key); })
            .reduce(function (acc, key) {
            acc[key] = req.headers[key];
            return acc;
        }, {});
        return filteredHeaders;
    };
}
function createLoggerMiddleware(confidentialHeaders) {
    if (confidentialHeaders === void 0) { confidentialHeaders = []; }
    express_winston_1.default.requestWhitelist.push("body");
    express_winston_1.default.responseWhitelist.push("body");
    return express_winston_1.default.logger({
        statusLevels: true,
        transports: [
            new winston_1.default.transports.Console(configs.winston.console),
            new winston_1.default.transports.File(configs.winston.file),
        ],
        requestFilter: filterRequestHeaders(confidentialHeaders),
    });
}
exports.createLoggerMiddleware = createLoggerMiddleware;
function createErrorLoggerMiddleware(confidentialHeaders) {
    if (confidentialHeaders === void 0) { confidentialHeaders = []; }
    return express_winston_1.default.errorLogger({
        transports: [
            new winston_1.default.transports.Console(configs.winston.console),
            new winston_1.default.transports.File(configs.winston.file),
        ],
        requestFilter: filterRequestHeaders(confidentialHeaders),
    });
}
exports.createErrorLoggerMiddleware = createErrorLoggerMiddleware;
var logger = winston_1.default.createLogger({
    transports: [
        new winston_1.default.transports.Console(configs.winston.console),
        new winston_1.default.transports.File(configs.winston.file),
    ],
    exitOnError: false,
});
exports.logger = logger;
logger.stream = Object.assign(logger.stream, {
    write: function (message) {
        logger.info(JSON.parse(message));
    },
});
